@@ -1,4 +1,4 @@
-use poem::{handler, route, route::post, web::Multipart, Server};
+use poem::{handler, listener::TcpListener, route, route::post, web::Multipart, Server};
 
 #[handler]
 async fn index(mut multipart: Multipart) {
@@ -19,6 +19,7 @@ async fn index(mut multipart: Multipart) {
 #[tokio::main]
 async fn main() {
     let app = route().at("/", post(index));
-    let server = Server::bind("127.0.0.1:3000").await.unwrap();
+    let listener = TcpListener::bind("127.0.0.1:3000");
+    let server = Server::new(listener).await.unwrap();
     server.run(app).await.unwrap();
 }
