@@ -216,7 +216,7 @@ impl Request {
     /// Returns the parameters used by the extractor.
     pub fn split(mut self) -> (Request, RequestBody) {
         let body = self.take_body();
-        (self, RequestBody::new(Some(body)))
+        (self, RequestBody::new(body))
     }
 }
 
